======
Numina
======

|zenodo| |docs| |pypi| 

This is Numina, the data reduction package used by the following
Gran Telescopio Canarias instruments: EMIR, FRIDA, MEGARA and MIRADAS.

You can install numina using
the `released code in PyPI <https://pypi.org/project/numina/>`_ or
the `development version in Github <https://github.com/guaix-ucm/numina>`_.

The installation instructions are available in the
`online documentation <https://numina.readthedocs.io/en/latest/user/install.html>`_
or `doc/user/install.rst <doc/user/install.rst>`_ in the source distribution.

Licensing
---------
Numina is distributed under GNU GPL, either version 3 of the License,
or (at your option) any later version. See the file LICENSE.txt for
details.

Authors
-------
Webpage: https://github.com/guaix-ucm/numina

Maintainers: Sergio Pascual sergiopr@fis.ucm.es, Nicolás Cardiel cardiel@ucm.es


.. |docs| image:: https://readthedocs.org/projects/numina/badge/?version=latest
    :alt: Documentation Status
    :target: http://numina.readthedocs.org/en/latest/?badge=latest

.. |zenodo| image:: https://zenodo.org/badge/doi/10.5281/zenodo.593638.svg
   :target: https://doi.org/10.5281/zenodo.593638
   :alt: Numina's Zenodo DOI

.. |pypi| image:: https://badge.fury.io/py/numina.svg
    :target: https://badge.fury.io/py/numina
    :alt: Numina's PyPI version

